/*==============================================================================
// 
//	File: ANEPIE.h
//
//	Argus Numerical Environments - Plug In Extension, Release 1.0
// 
//	Copyright  1996 Argus Holdings Ltd.  All rights reserved.
//
// THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF Argus Holdings Ltd..
// The copyright notice above does not evidence any
// actual or intended publication of such source code
//
//================================================================================
// Update information:
//	11/12/96 - Version 2. Add kPIEAnyLayer
//==============================================================================*/

#ifndef _ANEPIE_H_
#define _ANEPIE_H_

#define ANE_PIE_VERSION 2

typedef long ANE_INT32;

typedef short ANE_INT16;

typedef int ANE_BOOL;

typedef double ANE_DOUBLE;

typedef char *ANE_STR;
typedef const char *ANE_CSTR;

typedef void *ANE_PTR;
typedef const void *ANE_CPTR;

typedef struct ANEPointRec
{
	ANE_DOUBLE x;
	ANE_DOUBLE y;
} ANE_POINT;

typedef struct ANEPointRec * ANE_POINT_PTR;
typedef const struct ANEPointRec * ANE_POINT_CPTR;


typedef void (*GenericPIECall)();											/* generic PIE function call */

enum EPIEType	{
					kFunctionPIE				= 0x0001,		/* type of PIE function */
					kImportPIE				= 0x0002,
					kRenumberPIE			= 0x0004,
					kExportTemplatePIE	= 0x0008,
					kProjectPIE				= 0x0010,
					kInterpolationPIE		= 0x0020};

enum EPIENumberType	{
					kPIEBoolean				= 0x0010,
					kPIEInteger				= 0x0020,
					kPIEFloat					= 0x0030,
					kPIEString				= 0x1040,

					kPIENA						= 0x0032
									};

enum EPIEObjectType {
					kPIEContourObject		= 0x0001,
					kPIEBlockObject			=	0x0002,
					kPIEElementObject		=	0x0004,
					kPIENodeObject			= 0x0008,
					kPIEPictObject			= 0x0010
					};

enum EPIELayerType	{
					kPIEAnyLayer					= 0xffff,	/* since version 2 */
					kPIETriMeshLayer		= 0x1,
					kPIEQuadMeshLayer		= 0x2,
					kPIEInformationLayer	= 0x4,
					kPIEGridLayer			= 0x8,
					kPIEDataLayer			= 0x10,
					kPIEMapsLayer			= 0x20,
					kPIEDomainLayer			= 0x40
				};

enum EPIEParameterType	{
					kPIENullSubParam						= 0x0000,
					kPIELayerSubParam					= 0x0010,
						kPIEMeshLayerSubParam			= 0x0011,
						kPIEGridLayerSubParam			= 0x0012,
						kPIEContourLayerSubParam		= 0x0013,
						kPIEPictLayerSubParam			= 0x0014,
					kPIEElemSubParam					= 0x0020,
					kPIENodeSubParam					= 0x0040,
					kPIEBlockSubParam					= 0x0080,
					kPIEVertexSubParam					= 0x0100,
					kPIEGeneralSubParam				= 0x7FFF
										};

struct ANEPIEDesc
{

#ifdef __cplusplus
	public:
		ANEPIEDesc() {}

		ANEPIEDesc(
					ANE_STR		_vendor,
					ANE_STR		_product,
					ANE_STR		_name,
					EPIEType		_type,
					ANE_PTR		_descriptor)
			:	version(ANE_PIE_VERSION),
				vendor(_vendor),
				product(_product),
				name(_name),
				type(_type),
				descriptor(_descriptor)
			{ }
	
#endif
		
		ANE_INT32		version;
		ANE_STR			vendor;
		ANE_STR			product;
		ANE_STR			name;
		enum EPIEType	type;
		ANE_PTR			descriptor;
}; /* ANEPIEDesc */


#ifdef __cplusplus
extern "C" {
typedef void (*GetANEFunctionsPtr)(ANE_INT32& numNames, ANEPIEDesc**& descriptors);
}
#else
typedef void (*GetANEFunctionsPtr)(ANE_INT32* numNames, struct ANEPIEDesc*** descriptors);
#endif






#endif /* _ANEPIE_H_ */

/*==============================================================================
//	End File: ANEPIE.h
//============================================================================*/
